/*-
 * Copyright 2008 Jason Harmening
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 */

#ifndef __CX88_AUDIO_REGS_H__
#define __CX88_AUDIO_REGS_H__

#define CX23880_AUDIO_REG_IN_GP_COUNT           0x32C020
#define CX23880_AUDIO_REG_OUT_GP_COUNT          0x32C024
#define CX23885_AUDIO_REG_INTA_GP_COUNT         0x140020
#define CX23885_AUDIO_REG_INTB_GP_COUNT         0x140024
#define CX23885_AUDIO_REG_EXT_GP_COUNT          0x140120

#define CX23880_AUDIO_REG_IN_GP_COUNT_CONTROL   0x32C030
#define CX23880_AUDIO_REG_OUT_GP_COUNT_CONTROL  0x32C034
#define CX23885_AUDIO_REG_INTA_GP_COUNT_CONTROL 0x140030
#define CX23885_AUDIO_REG_INTB_GP_COUNT_CONTROL 0x140034
#define CX23885_AUDIO_REG_EXT_GP_COUNT_CONTROL  0x140130

#define CX23880_AUDIO_REG_DMA_CONTROL           0x32C040
#define CX23880_AUDIO_OUT_RISC_ENABLE           (1 << 5)
#define CX23880_AUDIO_IN_RISC_ENABLE            (1 << 4)
#define CX23880_AUDIO_OUT_FIFO_ENABLE           (1 << 1)
#define CX23880_AUDIO_IN_FIFO_ENABLE            (1 << 0)

#define CX23885_AUDIO_REG_INT_DMA_CONTROL       0x140040
#define CX23885_AUDIO_INTB_RISC_ENABLE          (1 << 5)
#define CX23885_AUDIO_INTA_RISC_ENABLE          (1 << 4)
#define CX23885_AUDIO_INTB_FIFO_ENABLE          (1 << 1)
#define CX23885_AUDIO_INTA_FIFO_ENABLE          (1 << 0)

#define CX23885_AUDIO_REG_EXT_DMA_CONTROL       0x140140
#define CX23885_AUDIO_EXT_RISC_ENABLE           (1 << 4)
#define CX23885_AUDIO_EXT_FIFO_ENABLE           (1 << 0)

#define CX23880_AUDIO_REG_IN_LINE_LENGTH        0x32C048
#define CX23885_AUDIO_REG_INTA_LINE_LENGTH      0x140050
#define CX23885_AUDIO_REG_INTB_LINE_LENGTH      0x140054
#define CX23885_AUDIO_REG_EXT_LINE_LENGTH       0x140150

#define CX23880_AUDIO_REG_INT_MASK              0x200060
#define CX23880_AUDIO_REG_INT_STAT              0x200064
#define CX23880_AUDIO_REG_INT_MSTAT             0x200068
#define CX23880_AUDIO_REG_INT_SSTAT             0x20006C
#define CX23880_AUDIO_INT_MODE_CHANGE           (1 << 21)
#define CX23880_AUDIO_INT_BER                   (1 << 20)
#define CX23880_AUDIO_INT_PCI_ABORT             (1 << 19)
#define CX23880_AUDIO_INT_RIP_ERR               (1 << 18)
#define CX23880_AUDIO_INT_PAR_ERR               (1 << 17)
#define CX23880_AUDIO_INT_OPCODE_ERR            (1 << 16)
#define CX23880_AUDIO_INT_OUT_SYNC              (1 << 13)
#define CX23880_AUDIO_INT_IN_SYNC               (1 << 12)
#define CX23880_AUDIO_INT_OUT_UNDERFLOW         (1 << 9)
#define CX23880_AUDIO_INT_IN_OVERFLOW           (1 << 8)
#define CX23880_AUDIO_INT_OUT_RISCI2            (1 << 5)
#define CX23880_AUDIO_INT_IN_RISCI2             (1 << 4)
#define CX23880_AUDIO_INT_OUT_RISCI1            (1 << 1)
#define CX23880_AUDIO_INT_IN_RISCI1             (1 << 0)

#define CX23885_AUDIO_REG_INT_INT_MASK          0x040050
#define CX23885_AUDIO_REG_INT_INT_STAT          0x040054
#define CX23885_AUDIO_REG_INT_INT_MSTAT         0x040058
#define CX23885_AUDIO_REG_INT_INT_SSTAT         0x04005C
#define CX23885_AUDIO_INT_INTB_OPCODE_ERR       (1 << 17)
#define CX23885_AUDIO_INT_INTA_OPCODE_ERR       (1 << 16)
#define CX23885_AUDIO_INT_INTB_SYNC             (1 << 13)
#define CX23885_AUDIO_INT_INTA_SYNC             (1 << 12)
#define CX23885_AUDIO_INT_INTB_OVERFLOW         (1 << 9)
#define CX23885_AUDIO_INT_INTA_OVERFLOW         (1 << 8)
#define CX23885_AUDIO_INT_INTB_RISCI2           (1 << 5)
#define CX23885_AUDIO_INT_INTA_RISCI2           (1 << 4)
#define CX23885_AUDIO_INT_INTB_RISCI1           (1 << 1)
#define CX23885_AUDIO_INT_INTA_RISCI1           (1 << 0)

#define CX23885_AUDIO_REG_EXT_INT_MASK          0x040060
#define CX23885_AUDIO_REG_EXT_INT_STAT          0x040064
#define CX23885_AUDIO_REG_EXT_INT_MSTAT         0x040068
#define CX23885_AUDIO_REG_EXT_INT_SSTAT         0x04006C
#define CX23885_AUDIO_INT_EXT_OPCODE_ERR        (1 << 16)
#define CX23885_AUDIO_INT_EXT_SYNC              (1 << 12)
#define CX23885_AUDIO_INT_EXT_OVERFLOW          (1 << 8)
#define CX23885_AUDIO_INT_EXT_RISCI2            (1 << 4)
#define CX23885_AUDIO_INT_EXT_RISCI1            (1 << 0)

#define CX23885_AUDIO_REG_INTA_MODE             0x140058
#define CX23885_AUDIO_REG_INTB_MODE             0x14005C
#define CX23885_AUDIO_REG_EXT_MODE              0x140158

#endif
