#-
# Copyright 2010 Jason Harmening
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the distribution.
#
# THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
# ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
# ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
# FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
# DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
# OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
# HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
# OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
# SUCH DAMAGE.
#
#

#include <sys/errno.h>
#include <sys/bus.h>
#include <sys/param.h>
#include <sys/lock.h>
#include <sys/mutex.h>
#include "cx88_video_ioctl.h"

INTERFACE cx88_video;

CODE {

   static int null_start_capture(device_t dev, cx88_video_capture *capture)
   {
      return ENXIO;
   }
   
   static void null_stop_capture(device_t dev)
   {
   }

   static int null_set_format(device_t dev, cx88_video_format *format)
   {
      return ENXIO;
   }
   
   static int null_get_info(device_t dev, cx88_video_status *status)
   {
      return ENXIO;
   }

   static int null_set_hue(device_t dev, uint8_t hue)
   {
      return ENXIO;
   }

   static int null_set_brightness(device_t dev, uint8_t brightness)
   {
      return ENXIO;
   }

   static int null_set_contrast(device_t dev, uint8_t contrast)
   {
      return ENXIO;
   }

   static int null_set_sat_u(device_t dev, uint8_t sat)
   {
      return ENXIO;
   }

   static int null_set_sat_v(device_t dev, uint8_t sat)
   {
      return ENXIO;
   }

   static int null_set_tdec(device_t dev, uint8_t fps)
   {
      return ENXIO;
   }

};

# Start video capture
METHOD int start_capture {
   device_t dev;
   cx88_video_capture *cap;
} DEFAULT null_start_capture;

# Stop video capture
METHOD void stop_capture {
   device_t dev;
} DEFAULT null_stop_capture;

# Set video standard and pixel format
METHOD int set_format {
   device_t dev;
   cx88_video_format *format;
} DEFAULT null_set_format;

# Retrieve signal/carrier status
METHOD int get_info {
   device_t dev;
   cx88_video_status *status;
} DEFAULT null_get_info;

# Set hue on a scale of 0..255
METHOD int set_hue {
   device_t dev;
   uint8_t hue;
} DEFAULT null_set_hue;

# Set brightness on a scale of 0..255
METHOD int set_brightness {
   device_t dev;
   uint8_t brightness;
} DEFAULT null_set_brightness;

# Set contrast on a scale of 0..255
METHOD int set_contrast {
   device_t dev;
   uint8_t contrast;
} DEFAULT null_set_contrast;

# Set saturation for U chroma, on a scale of 0..255
METHOD int set_sat_u {
   device_t dev;
   uint8_t sat;
} DEFAULT null_set_sat_u;

# Set saturation for V chroma, on a scale of 0..255
METHOD int set_sat_v {
   device_t dev;
   uint8_t sat;
} DEFAULT null_set_sat_v;

# Drop a specified number of frames per second (temporal decimation)
METHOD int set_tdec {
   device_t dev;
   uint8_t fps;
} DEFAULT null_set_tdec;

